@@ -1,5 +1,6 @@
 #' Retrieve readables editrules from an editmatrix
 #'
+#' THIS FUNCTION IS OBSOLETE AND WILL BE REMOVED. Use \link{as.data.frame} or \code{as.editmatrix} instead.
 #' \code{editrules} returns a data.frame describing the editrules in editmatrix \code{x}. This data.frame can be used to store the
 #' editrules in a readable format, so that the editrules can be maintained and documented.
 #'
@@ -14,6 +15,7 @@
 #' @param x \code{\link{editmatrix}}  or \code{matrix} object
 #' @return \code{data.frame} with information on all edit rules / constraints
 editrules <- function(x){
+   warning("Function 'editrules' is obsolete and will be removed in the next release. Use as.data.frame instead")
    x <- as.editmatrix(x)
    edit <- as.character(x)
    er <- data.frame(name=names(edit), edit=edit, stringsAsFactors=FALSE)
@@ -38,39 +40,7 @@ getb <- function(E){
   E[,ncol(E)]
 }
 
-#' Returns the derivation history of an edit matrix or array
-#'
-#' eliminate tracks the history of edits in a logical array H.
-#' H has nrow(E) rows and the number of columns is the number of
-#' edits in the editmatrix/array as it was first defined. If 
-#' H[i,j1], H[i,j2],...,H[i,jn] are TRUE, then E[i,] is some 
-#' (positive, linear) combination of original edits E[j1,], E[j2,],...,E[jn,]
-#'
-#' Attributes H and h are used to detect redundant derived edits.
-#'
-#' @param E \code{\link{editmatrix}}
-#' @rdname geth
-#' @seealso \code{\link{editmatrix}}, \code{\link{eliminate}}
-#'
-#' @example ../examples/eliminate.R
-#'
-#' @export
-getH <- function(E){
-    if ( !is.editmatrix(E)  ) stop("E has to be an editmatrix")
-    attr(E,"H")  
-}
 
-#' Returns the number of elimination steps performed on an edit matrix or arrat
-#'
-#' h records the number of variables eliminated from E by \code{\link{eliminate}}
-#'
-#' @rdname geth
-#' @seealso \code{\link{editmatrix}}, \code{\link{eliminate}}
-#' @export
-geth <- function(E){
-    if ( !is.editmatrix(E) ) stop("E has to be an editmatrix")
-    attr(E,"h")  
-}
 
 #' Returns the coefficient matrix \code{A} of linear (in)equalities
 #'
